@@ -1,4 +1,4 @@
-/* C code produced by gperf version 3.0.2 */
+/* C code produced by gperf version 3.0.3 */
 /* Command-line: gperf --output-file atoms.c atoms.gperf  */
 /* Computed positions: -k'3,6,9,$' */
 
@@ -315,6 +315,9 @@ static const struct stringpool_t stringpool_contents =
 #define stringpool ((const char *) &stringpool_contents)
 #ifdef __GNUC__
 __inline
+#ifdef __GNUC_STDC_INLINE__
+__attribute__ ((__gnu_inline__))
+#endif
 #endif
 const struct atom_map *
 in_word_set (str, len)
@@ -334,171 +337,171 @@ in_word_set (str, len)
     {
       {-1}, {-1}, {-1}, {-1},
 #line 103 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str4,86},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str4,18},
       {-1},
 #line 147 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str6,130},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str6,62},
       {-1}, {-1},
 #line 148 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str9,131},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str9,63},
 #line 106 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str10,89},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str10,21},
 #line 143 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str11,126},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str11,58},
       {-1}, {-1},
 #line 128 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str14,111},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str14,43},
 #line 151 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str15,134},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str15,66},
 #line 90 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str16,73},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str16,5},
 #line 104 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str17,87},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str17,19},
       {-1},
 #line 146 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str19,129},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str19,61},
       {-1}, {-1}, {-1}, {-1},
 #line 150 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str24,133},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str24,65},
       {-1},
 #line 138 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str26,121},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str26,53},
 #line 139 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str27,122},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str27,54},
 #line 114 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str28,97},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str28,29},
 #line 131 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str29,114},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str29,46},
       {-1}, {-1},
 #line 110 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str32,93},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str32,25},
 #line 91 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str33,74},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str33,6},
       {-1}, {-1},
 #line 93 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str36,76},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str36,8},
 #line 121 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str37,104},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str37,36},
 #line 120 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str38,103},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str38,35},
       {-1}, {-1},
 #line 101 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str41,84},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str41,16},
 #line 113 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str42,96},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str42,28},
 #line 102 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str43,85},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str43,17},
       {-1},
 #line 112 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str45,95},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str45,27},
 #line 118 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str46,101},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str46,33},
 #line 111 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str47,94},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str47,26},
 #line 136 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str48,119},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str48,51},
       {-1}, {-1},
 #line 115 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str51,98},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str51,30},
       {-1},
 #line 117 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str53,100},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str53,32},
 #line 107 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str54,90},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str54,22},
       {-1},
 #line 100 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str56,83},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str56,15},
 #line 124 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str57,107},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str57,39},
 #line 141 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str58,124},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str58,56},
       {-1}, {-1},
 #line 135 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str61,118},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str61,50},
 #line 86 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str62,69},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str62,1},
 #line 92 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str63,75},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str63,7},
 #line 137 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str64,120},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str64,52},
 #line 142 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str65,125},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str65,57},
 #line 108 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str66,91},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str66,23},
 #line 122 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str67,105},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str67,37},
 #line 109 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str68,92},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str68,24},
       {-1},
 #line 125 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str70,108},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str70,40},
 #line 99 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str71,82},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str71,14},
       {-1},
 #line 152 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str73,135},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str73,67},
       {-1},
 #line 119 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str75,102},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str75,34},
 #line 98 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str76,81},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str76,13},
       {-1},
 #line 133 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str78,116},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str78,48},
 #line 89 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str79,72},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str79,4},
 #line 129 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str80,112},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str80,44},
 #line 153 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str81,136},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str81,68},
 #line 123 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str82,106},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str82,38},
 #line 127 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str83,110},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str83,42},
 #line 130 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str84,113},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str84,45},
 #line 144 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str85,127},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str85,59},
 #line 105 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str86,88},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str86,20},
       {-1}, {-1}, {-1},
 #line 145 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str90,128},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str90,60},
 #line 134 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str91,117},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str91,49},
 #line 140 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str92,123},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str92,55},
 #line 88 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str93,71},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str93,3},
       {-1}, {-1},
 #line 97 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str96,80},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str96,12},
       {-1},
 #line 126 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str98,109},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str98,41},
       {-1}, {-1},
 #line 96 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str101,79},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str101,11},
       {-1}, {-1}, {-1}, {-1},
 #line 95 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str106,78},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str106,10},
       {-1},
 #line 132 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str108,115},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str108,47},
       {-1}, {-1},
 #line 94 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str111,77},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str111,9},
       {-1}, {-1}, {-1}, {-1},
 #line 116 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str116,99},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str116,31},
       {-1}, {-1}, {-1}, {-1},
 #line 149 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str121,132},
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str121,64},
       {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
       {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
       {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1}, {-1},
 #line 87 "atoms.gperf"
-      {(int)(long)&((struct stringpool_t *)0)->stringpool_str149,70}
+      {(int)(long)&((struct stringpool_t *)0)->stringpool_str149,2}
     };
 
   if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
@@ -521,75 +524,147 @@ in_word_set (str, len)
 }
 #line 154 "atoms.gperf"
 
-static const char *const atom_names[] = {
-	"PRIMARY",
-	"SECONDARY",
-	"ARC",
-	"ATOM",
-	"BITMAP",
-	"CARDINAL",
-	"COLORMAP",
-	"CURSOR",
-	"CUT_BUFFER0",
-	"CUT_BUFFER1",
-	"CUT_BUFFER2",
-	"CUT_BUFFER3",
-	"CUT_BUFFER4",
-	"CUT_BUFFER5",
-	"CUT_BUFFER6",
-	"CUT_BUFFER7",
-	"DRAWABLE",
-	"FONT",
-	"INTEGER",
-	"PIXMAP",
-	"POINT",
-	"RECTANGLE",
-	"RESOURCE_MANAGER",
-	"RGB_COLOR_MAP",
-	"RGB_BEST_MAP",
-	"RGB_BLUE_MAP",
-	"RGB_DEFAULT_MAP",
-	"RGB_GRAY_MAP",
-	"RGB_GREEN_MAP",
-	"RGB_RED_MAP",
-	"STRING",
-	"VISUALID",
-	"WINDOW",
-	"WM_COMMAND",
-	"WM_HINTS",
-	"WM_CLIENT_MACHINE",
-	"WM_ICON_NAME",
-	"WM_ICON_SIZE",
-	"WM_NAME",
-	"WM_NORMAL_HINTS",
-	"WM_SIZE_HINTS",
-	"WM_ZOOM_HINTS",
-	"MIN_SPACE",
-	"NORM_SPACE",
-	"MAX_SPACE",
-	"END_SPACE",
-	"SUPERSCRIPT_X",
-	"SUPERSCRIPT_Y",
-	"SUBSCRIPT_X",
-	"SUBSCRIPT_Y",
-	"UNDERLINE_POSITION",
-	"UNDERLINE_THICKNESS",
-	"STRIKEOUT_ASCENT",
-	"STRIKEOUT_DESCENT",
-	"ITALIC_ANGLE",
-	"X_HEIGHT",
-	"QUAD_WIDTH",
-	"WEIGHT",
-	"POINT_SIZE",
-	"RESOLUTION",
-	"COPYRIGHT",
-	"NOTICE",
-	"FONT_NAME",
-	"FAMILY_NAME",
-	"FULL_NAME",
-	"CAP_HEIGHT",
-	"WM_CLASS",
-	"WM_TRANSIENT_FOR",
+
+static const char atom_names[] =
+	"PRIMARY\0"
+	"SECONDARY\0"
+	"ARC\0"
+	"ATOM\0"
+	"BITMAP\0"
+	"CARDINAL\0"
+	"COLORMAP\0"
+	"CURSOR\0"
+	"CUT_BUFFER0\0"
+	"CUT_BUFFER1\0"
+	"CUT_BUFFER2\0"
+	"CUT_BUFFER3\0"
+	"CUT_BUFFER4\0"
+	"CUT_BUFFER5\0"
+	"CUT_BUFFER6\0"
+	"CUT_BUFFER7\0"
+	"DRAWABLE\0"
+	"FONT\0"
+	"INTEGER\0"
+	"PIXMAP\0"
+	"POINT\0"
+	"RECTANGLE\0"
+	"RESOURCE_MANAGER\0"
+	"RGB_COLOR_MAP\0"
+	"RGB_BEST_MAP\0"
+	"RGB_BLUE_MAP\0"
+	"RGB_DEFAULT_MAP\0"
+	"RGB_GRAY_MAP\0"
+	"RGB_GREEN_MAP\0"
+	"RGB_RED_MAP\0"
+	"STRING\0"
+	"VISUALID\0"
+	"WINDOW\0"
+	"WM_COMMAND\0"
+	"WM_HINTS\0"
+	"WM_CLIENT_MACHINE\0"
+	"WM_ICON_NAME\0"
+	"WM_ICON_SIZE\0"
+	"WM_NAME\0"
+	"WM_NORMAL_HINTS\0"
+	"WM_SIZE_HINTS\0"
+	"WM_ZOOM_HINTS\0"
+	"MIN_SPACE\0"
+	"NORM_SPACE\0"
+	"MAX_SPACE\0"
+	"END_SPACE\0"
+	"SUPERSCRIPT_X\0"
+	"SUPERSCRIPT_Y\0"
+	"SUBSCRIPT_X\0"
+	"SUBSCRIPT_Y\0"
+	"UNDERLINE_POSITION\0"
+	"UNDERLINE_THICKNESS\0"
+	"STRIKEOUT_ASCENT\0"
+	"STRIKEOUT_DESCENT\0"
+	"ITALIC_ANGLE\0"
+	"X_HEIGHT\0"
+	"QUAD_WIDTH\0"
+	"WEIGHT\0"
+	"POINT_SIZE\0"
+	"RESOLUTION\0"
+	"COPYRIGHT\0"
+	"NOTICE\0"
+	"FONT_NAME\0"
+	"FAMILY_NAME\0"
+	"FULL_NAME\0"
+	"CAP_HEIGHT\0"
+	"WM_CLASS\0"
+	"WM_TRANSIENT_FOR\0"
+;
+
+static const uint16_t atom_name_offsets[] = {
+	0,
+	8,
+	18,
+	22,
+	27,
+	34,
+	43,
+	52,
+	59,
+	71,
+	83,
+	95,
+	107,
+	119,
+	131,
+	143,
+	155,
+	164,
+	169,
+	177,
+	184,
+	190,
+	200,
+	217,
+	231,
+	244,
+	257,
+	273,
+	286,
+	300,
+	312,
+	319,
+	328,
+	335,
+	346,
+	355,
+	373,
+	386,
+	399,
+	407,
+	423,
+	437,
+	451,
+	461,
+	472,
+	482,
+	492,
+	506,
+	520,
+	532,
+	544,
+	563,
+	583,
+	600,
+	618,
+	631,
+	640,
+	651,
+	658,
+	669,
+	680,
+	690,
+	697,
+	707,
+	719,
+	729,
+	740,
+	749,
 };
 
 xcb_atom_t intern_atom_predefined(uint16_t name_len, const char *name)
@@ -641,9 +716,9 @@ xcb_atom_t intern_atom_fast_reply(xcb_connection_t *c, intern_atom_fast_cookie_t
 
 const char *get_atom_name_predefined(xcb_atom_t atom)
 {
-	if(atom <= 0 || atom > (sizeof(atom_names) / sizeof(*atom_names)))
+	if(atom <= 0 || atom > (sizeof(atom_name_offsets) / sizeof(*atom_name_offsets)))
 		return 0;
-	return atom_names[atom - 1];
+	return atom_names + atom_name_offsets[atom - 1];
 }
 
 int get_atom_name(xcb_connection_t *c, xcb_atom_t atom, const char **namep, int *lengthp)
